#ifndef _CANVAS_H
#define _CANVAS_H

#ifdef HAVE_SDL
#include "SDL.h"
#endif
#ifdef HAVE_GLX
#include <GL/glx.h>
#endif

class GLCanvas {
#ifdef HAVE_SDL
    SDL_Surface *surface;
#endif
#ifdef HAVE_GLX
    Window window;
    Display *display;
    int screen;
#endif

    bool need_refresh; 	// do we need to redraw the canvas?

    // get current millisecond (arbitrary reference: used for change in millis)
    GLuint get_millis();
    // create the window (either SDL or GLX)
    int create_window();
public:
#ifdef HAVE_GLX
    Window window_id;
#endif
    bool full_screen;	// use full screen?
    bool sdl_window;	// try to open an SDL window (fails if !HAVE_SDL)
    double spf;		// seconds per frame (ie, 1/30 spf instead of 30 fps)
    int width;
    int height;

    GLCanvas();

    // initialize the window and GL stuff
    int init();
    // resize the viewport and apply frustum transformation
    void resize();
    // repaint what's on the canvas
    void draw();
    // the event loop. handles events and animates the game
    // returns 0 on successful quit, 1 on error.
    int loop();

#ifdef HAVE_SDL
    // handle a mouse drag event
    void mouse_drag(SDL_MouseMotionEvent& event);
#endif
};

#endif // canvas.h
